Oasis


Notes
-----

The Open Access Series of Imaging Studies (OASIS) is a project aimed
at making MRI data sets of the brain freely available to the scientific community.

OASIS is made available by the Washington University Alzheimer’s Disease
Research Center, Dr. Randy Buckner at the Howard Hughes Medical
Institute (HHMI) at Harvard University, the Neuroinformatics Research
Group (NRG) at Washington University School of Medicine, and the Biomedical
Informatics Research Network (BIRN).


Content
-------
    :'gray_matter_maps': Nifti images with gray matter density probability
    :'white_matter_maps': Nifti images with white matter density probability maps
    :'ext_vars': Behavioral information on the participants
    :'data_usage_agreement': Text file containing the data usage agreement


References
----------
For more information about this dataset's structure:
http://www.oasis-brains.org/

Open Access Series of Imaging Studies (OASIS): Cross-sectional MRI
Data in Young, Middle Aged, Nondemented, and Demented Older Adults.
Marcus, D. S and al., 2007, Journal of Cognitive Neuroscience.


Licence: provided under an open access data use agreement (DUA).